Index: /trunk/src/VBox/Frontends/VirtualBox/src/medium/UIMedium.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/medium/UIMedium.h	(revision 55102)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/medium/UIMedium.h	(revision 55103)
@@ -155,9 +155,4 @@
     QString parentID() const { return m_strParentId; }
 
-    /** Returns medium root. */
-    UIMedium root() const;
-    /** Returns medium parent. */
-    UIMedium parent() const;
-
     /** Updates medium parent. */
     void updateParentID();
@@ -289,4 +284,9 @@
 private:
 
+    /** Returns medium root. */
+    UIMedium root() const;
+    /** Returns medium parent. */
+    UIMedium parent() const;
+
     /** Checks if m_noDiffs is filled in and does it if not.
       * @param fNoDiffs @if false, this method immediately returns. */

Index: /trunk/src/VBox/Frontends/VirtualBox/src/medium/UIMedium.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/medium/UIMedium.cpp	(revision 55102)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/medium/UIMedium.cpp	(revision 55103)
@@ -367,16 +367,4 @@
 }
 
-UIMedium UIMedium::root() const
-{
-    /* Redirect call to VBoxGlobal: */
-    return vboxGlobal().medium(m_strRootId);
-}
-
-UIMedium UIMedium::parent() const
-{
-    /* Redirect call to VBoxGlobal: */
-    return vboxGlobal().medium(m_strParentId);
-}
-
 void UIMedium::updateParentID()
 {
@@ -409,6 +397,6 @@
         if (fCheckRO && m_fReadOnly)
             strTip += m_sstrRow.arg("<hr>") +
-                      m_sstrRow.arg(VBoxGlobal::tr("Attaching this hard disk will be performed indirectly using "
-                                                   "a newly created differencing hard disk.", "medium"));
+                      m_sstrRow.arg(VBoxGlobal::tr("Attaching this hard drive will be performed indirectly using "
+                                                   "a newly created differencing hard drive.", "medium"));
     }
 
@@ -438,12 +426,12 @@
     // @todo the below check is rough; if m_medium becomes uninitialized, any
     // of getters called afterwards will also fail. The same relates to the
     // root hard disk object (that will be the hard disk itself in case of
     // non-differencing disks). However, this check was added to fix a
     // particular use case: when the hard disk is a differencing hard disk and
     // it happens to be discarded (and uninitialized) after this method is
     // called but before we read all its properties (yes, it's possible!), the
     // root object will be null and calling methods on it will assert in the
     // debug builds. This check seems to be enough as a quick solution (fresh
     // hard disk attachments will be re-read by a machine state change signal
     // after the discard operation is finished, so the user will eventually see
     // correct data), but in order to solve the problem properly we need to use
@@ -533,4 +521,16 @@
 }
 
+UIMedium UIMedium::root() const
+{
+    /* Redirect call to VBoxGlobal: */
+    return vboxGlobal().medium(m_strRootId);
+}
+
+UIMedium UIMedium::parent() const
+{
+    /* Redirect call to VBoxGlobal: */
+    return vboxGlobal().medium(m_strParentId);
+}
+
 void UIMedium::checkNoDiffs(bool fNoDiffs)
 {
@@ -548,8 +548,7 @@
 
             if (m_noDiffs.toolTip.isNull())
-                m_noDiffs.toolTip = m_sstrRow.arg(VBoxGlobal::tr("Some of the files in this hard disk chain "
-                                                                 "are inaccessible. Please use the Virtual Media "
-                                                                 "Manager in <b>Show Differencing Hard Disks</b> "
-                                                                 "mode to inspect these files.", "medium"));
+                m_noDiffs.toolTip = m_sstrRow.arg(VBoxGlobal::tr("Some of the files in this hard drive chain "
+                                                                 "are inaccessible. Please use the Virtual Medium "
+                                                                 "Manager to inspect these files.", "medium"));
 
             if (!parentMedium.m_result.isOk())
@@ -565,6 +564,6 @@
         m_noDiffs.toolTip = root().tip() +
                             m_sstrRow.arg("<hr>") +
-                            m_sstrRow.arg(VBoxGlobal::tr("This base hard disk is indirectly attached using "
-                                                         "the following differencing hard disk:", "medium")) +
+                            m_sstrRow.arg(VBoxGlobal::tr("This base hard drive is indirectly attached using "
+                                                         "the following differencing hard drive:", "medium")) +
                             m_strToolTip + m_noDiffs.toolTip;
     }
@@ -438,12 +426,12 @@
     // @todo the below check is rough; if m_medium becomes uninitialized, any
     // of getters called afterwards will also fail. The same relates to the
-    // root hard disk object (that will be the hard disk itself in case of
+    // root hard drive object (that will be the hard drive itself in case of
     // non-differencing disks). However, this check was added to fix a
@@ -438,12 +426,12 @@
     // non-differencing disks). However, this check was added to fix a
-    // particular use case: when the hard disk is a differencing hard disk and
+    // particular use case: when the hard drive is a differencing hard drive and
     // it happens to be discarded (and uninitialized) after this method is
     // called but before we read all its properties (yes, it's possible!), the
@@ -438,12 +426,12 @@
     // root object will be null and calling methods on it will assert in the
     // debug builds. This check seems to be enough as a quick solution (fresh
-    // hard disk attachments will be re-read by a machine state change signal
+    // hard drive attachments will be re-read by a machine state change signal
     // after the discard operation is finished, so the user will eventually see
     // correct data), but in order to solve the problem properly we need to use